@@ -95,10 +95,14 @@ gimp_buffer_use (GimpBuffer        *buffer,
                  GimpPoint         *tile,
                  Use                how)
 {
+  GimpPoint p = {0,0};
+
   g_return_val_if_fail (buffer != NULL, NULL);
   g_return_val_if_fail (buffer->klass != NULL, NULL);
   g_return_val_if_fail (K->use != NULL, NULL);
-  g_return_val_if_fail (tile != NULL, NULL);
+
+  if (tile == NULL)
+    tile = &p;
   
   if (! gp_tile_ok (buffer, tile)) return NULL;
 
