@@ -45,9 +45,6 @@ struct _GimpTileBuffer
   /* we are a GimpBuffer subclass */
   GimpBuffer buffer;
 
-  /* the number of tiles */
-  gint ntiles;
-
   /* the actual image data */
   GimpTile * tiles;
 };
