@@ -3,7 +3,7 @@
 #include <string.h>
 #include <gtk/gtk.h>
 
-#include "memory.h"
+#include "cow.h"
 
 #define SIZE 10
 
