@@ -117,3 +117,63 @@ tile_data_pointer (Tile *t,
   return (void*) data;
 }
 
+
+
+TempBuf *
+temp_buf_new (gint    width,
+              gint    height,
+              gint    bytes,
+              gint    x,
+              gint    y,
+              guchar *col)
+{
+  GimpFlatBuffer * f;
+  GimpBuffer * b;
+
+  f = gimp_flat_buffer_new (bytes, width, height);
+  b = GIMP_BUFFER(f);
+  
+  b->qq_x = x;
+  b->qq_y = y;
+
+  if (col != NULL)
+    {
+      GimpMemPtr * d;
+      GimpPoint p;
+
+      p.x = p.y = 0;
+      d = gimp_buffer_use (b, &p, USE_WRITE);
+
+      if (d != NULL)
+        {
+          guchar * dp = guchar_d (d);
+          gint xx, yy, bb;
+          
+          for (yy = height; yy; --yy)
+            {
+              for (xx = width; xx; --xx)
+                {
+                  for (bb = 0; bb < bytes; ++bb)
+                    {
+                      *dp++ = col[bb];
+                    }
+                }
+            }
+          
+          gimp_buffer_use (b, &p, USE_RELEASE);
+        }
+    }
+
+  return b;
+}
+
+
+MaskBuf *
+mask_buf_new (gint  width,
+              gint  height)
+{
+  static unsigned char empty = 0;
+
+  return (temp_buf_new (width, height, 1, 0, 0, &empty));
+}
+
